@@ -1,12 +1,16 @@
 use crate::events::event_handler::EventHandler;
 use crate::namespace::Namespace;
+use crate::protocol::AsyncProtocolStream;
 
 pub trait NamespaceProvider {
-    fn name() -> String;
-    fn register(handler: &mut EventHandler);
+    fn name() -> &'static str;
+    fn register<S: AsyncProtocolStream>(handler: &mut EventHandler<S>);
 }
 
-impl Namespace {
+impl<S> Namespace<S>
+where
+    S: AsyncProtocolStream,
+{
     pub fn from_provider<N: NamespaceProvider>() -> Self {
         let name = N::name();
         let mut handler = EventHandler::new();
